Logical; if TRUE, manufacturer is searched on instead
of make.
start_year
Start of year range (optional).
end_year
End of year range (optional).
api_key
API access key to use, if not set in environment.
Value
A tibble providing the count of recalls from the Vehicle Recalls.
Details
Queries the Vehicle Recalls Database API by make or manufacturer and returns
the count of recalls in the database. The year range of the search can be
specified and is based on the manufactured year and not the year a recall
occurred.
The API key can be set in the environment using
Sys.setenv(VRD_API = 'your_API_key_here') and will be used by the
function, or can be passed into the function using the api_key
argument.