Queries the Vehicle Recalls Database API by recall number and returns
summary recall information.
An API key is required to run the function and query the Vehicle Recalls
Database. The key can be acquired at
https://tc.api.canada.ca/en/detail?api=VRDB.
The API key can be set in the environment using
Sys.setenv(VRD_API = 'your_API_key_here') and will be used by the
function, or can be passed into the function using the api_key
argument.