Queries the Vehicle Recalls Database API by year range and returns
summary recall information. If start_year and/or end_year are
not specified, the function will default to the start and/or end years
available in the database. Note that the year range is based on the
manufactured year and not the year a recall occurred.
An API key is required to run the function and query the Vehicle Recalls
Database. The key can be acquired at
https://tc.api.canada.ca/en/detail?api=VRDB.
The API key can be set in the environment using
Sys.setenv(VRD_API = 'your_API_key_here') and will be used by the
function, or can be passed into the function using the api_key
argument.